==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/d1/d109c836a466dcc3dcb303ac38648622.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @MauticCore/Default/head.html.twig */
class __TwigTemplate_a42fdbbc2cbee1df414cf6d3e5bed896 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "
<head>
    <meta charset=\"UTF-8\" />
    <title>
        ";
        // line 5
        if ((array_key_exists("headerTitle", $context) &&  !Twig\Extension\CoreExtension::testEmpty((isset($context["headerTitle"]) || array_key_exists("headerTitle", $context) ? $context["headerTitle"] : (function () { throw new RuntimeError('Variable "headerTitle" does not exist.', 5, $this->source); })())))) {
            // line 6
            yield "            ";
            yield $this->env->getRuntime('Exercise\HTMLPurifierBundle\Twig\HTMLPurifierRuntime')->purify(Twig\Extension\CoreExtension::striptags(Twig\Extension\CoreExtension::replace((isset($context["headerTitle"]) || array_key_exists("headerTitle", $context) ? $context["headerTitle"] : (function () { throw new RuntimeError('Variable "headerTitle" does not exist.', 6, $this->source); })()), ["<" => " <"])));
            yield " |
        ";
        }
        // line 8
        yield "        ";
        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape(((array_key_exists("pageTitle", $context)) ? (Twig\Extension\CoreExtension::default((isset($context["pageTitle"]) || array_key_exists("pageTitle", $context) ? $context["pageTitle"] : (function () { throw new RuntimeError('Variable "pageTitle" does not exist.', 8, $this->source); })()), "FPÖ")) : ("FPÖ")), "html", null, true);
        yield "
    </title>
    <meta name=\"viewport\" content=\"width=device-width, initial-scale=1, maximum-scale=1\">
    <link rel=\"icon\" type=\"image/x-icon\" href=\"/themes/system/CoreBundle/Assets/img/favicon.ico\" />
    <link rel=\"icon\" sizes=\"192x192\" href=\"/themes/system/CoreBundle/Assets/img/favicon.ico\">
    <link rel=\"apple-touch-icon\" href=\"/themes/system/CoreBundle/Assets/img/favicon.ico\" />

    ";
        // line 15
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputSystemStylesheets();
        yield "

    ";
        // line 17
        yield from         $this->loadTemplate("@MauticCore/Default/script.html.twig", "@MauticCore/Default/head.html.twig", 17)->unwrap()->yield($context);
        // line 18
        yield "
    ";
        // line 19
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputHeadDeclarations();
        yield "
</head>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@MauticCore/Default/head.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  77 => 19,  74 => 18,  72 => 17,  67 => 15,  56 => 8,  50 => 6,  48 => 5,  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@MauticCore/Default/head.html.twig", "/var/www/html/mauticGIT-Test/themes/system/CoreBundle/Resources/views/Default/head.html.twig");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/d1/d109c836a466dcc3dcb303ac38648622.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @MauticCore/Default/head.html.twig */
class __TwigTemplate_a42fdbbc2cbee1df414cf6d3e5bed896 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "
<head>
    <meta charset=\"UTF-8\" />
    <title>
        ";
        // line 5
        if ((array_key_exists("headerTitle", $context) &&  !Twig\Extension\CoreExtension::testEmpty((isset($context["headerTitle"]) || array_key_exists("headerTitle", $context) ? $context["headerTitle"] : (function () { throw new RuntimeError('Variable "headerTitle" does not exist.', 5, $this->source); })())))) {
            // line 6
            yield "            ";
            yield $this->env->getRuntime('Exercise\HTMLPurifierBundle\Twig\HTMLPurifierRuntime')->purify(Twig\Extension\CoreExtension::striptags(Twig\Extension\CoreExtension::replace((isset($context["headerTitle"]) || array_key_exists("headerTitle", $context) ? $context["headerTitle"] : (function () { throw new RuntimeError('Variable "headerTitle" does not exist.', 6, $this->source); })()), ["<" => " <"])));
            yield " |
        ";
        }
        // line 8
        yield "        ";
        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape(((array_key_exists("pageTitle", $context)) ? (Twig\Extension\CoreExtension::default((isset($context["pageTitle"]) || array_key_exists("pageTitle", $context) ? $context["pageTitle"] : (function () { throw new RuntimeError('Variable "pageTitle" does not exist.', 8, $this->source); })()), "Cause Buzz")) : ("Cause Buzz")), "html", null, true);
        yield "
    </title>
    <meta name=\"viewport\" content=\"width=device-width, initial-scale=1, maximum-scale=1\">
    <link rel=\"icon\" type=\"image/x-icon\" href=\"/themes/system/CoreBundle/Assets/img/favicon.ico\" />
    <link rel=\"icon\" sizes=\"192x192\" href=\"/themes/system/CoreBundle/Assets/img/favicon.ico\">
    <link rel=\"apple-touch-icon\" href=\"/themes/system/CoreBundle/Assets/img/favicon.ico\" />

    ";
        // line 15
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputSystemStylesheets();
        yield "

    ";
        // line 17
        yield from         $this->loadTemplate("@MauticCore/Default/script.html.twig", "@MauticCore/Default/head.html.twig", 17)->unwrap()->yield($context);
        // line 18
        yield "
    ";
        // line 19
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputHeadDeclarations();
        yield "
</head>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@MauticCore/Default/head.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  77 => 19,  74 => 18,  72 => 17,  67 => 15,  56 => 8,  50 => 6,  48 => 5,  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@MauticCore/Default/head.html.twig", "/var/www/html/production-demo/themes/system/CoreBundle/Resources/views/Default/head.html.twig");
    }
}
